# kallithea font demo

show codes
• icon-circle0x2022
← icon-right-open0x2190
↑ icon-up-open0x2191
→ icon-left-open0x2192
↓ icon-down-open0x2193
↔ icon-code0x2194
↕ icon-sort0x2195
⇄ icon-exchange0x21c4
⊕ icon-plus-circled0x2295
⊖ icon-minus-circled0x2296
⊞ icon-diff-added0x229e
⊟ icon-diff-removed0x229f
⊡ icon-diff-modified0x22a1
⌚ icon-clock0x231a
⏴ icon-triangle-left0x23f4
⏵ icon-triangle-right0x23f5
⏶ icon-triangle-up0x23f6
⏷ icon-triangle-down0x23f7
◦ icon-circle-empty0x25e6
♡ icon-heart-empty0x2661
♥ icon-heart0x2665
⚙ icon-cog-alt0x2699
⛃ icon-database0x26c3
⛭ icon-gear0x26ed
➕ icon-plus0x2795
➖ icon-minus0x2796
⭥ icon-resize-vertical0x2b65
⭱ icon-move-up0x2b71
⭳ icon-move-down0x2b73
 icon-file-submodule0xe801
 icon-git-merge0xe802
 icon-ruler0xe811
 icon-download-cloud0xe813
 icon-upload-cloud0xe814
 icon-graph0xe815
 icon-file-zip0xe816
 icon-file-code0xe81a
 icon-doc-text-inv0xe81c
 icon-diff0xe81d
 icon-diff-ignored0xe81e
 icon-diff-renamed0xe81f
 icon-paste0xe820
 icon-file-directory0xe823
 icon-git-compare0xe824
 icon-git-pull-request0xe825
 icon-repo-forked0xe827
 icon-fork0xe828
 icon-docs0xe834
 icon-doc-inv0xe836
 icon-file-powerpoint0xe837
 icon-tags0xe83d
 icon-bookmark-empty0xe83f
 icon-bookmark0xe840
 icon-align-left0xe841
 icon-sliders0xe843
 icon-eye-off0xe851
 icon-rss0xe855
 icon-rss-squared0xe856
 icon-strike0xe859
 icon-box0xe85e
 icon-right0xe85f
 icon-left0xe860
 icon-left-circled0xe861
 icon-right-circled0xe862
 icon-up-circled0xe863
 icon-up0xe864
 icon-down0xe865
 icon-down-circled0xe866
🌎 icon-globe0x1f30e
👁 icon-eye0x1f441
👤 icon-user0x1f464
👥 icon-users0x1f465
💾 icon-floppy0x1f4be
📁 icon-folder-empty0x1f4c1
📂 icon-folder-open-empty0x1f4c2
📋 icon-clippy0x1f4cb
📒 icon-book0x1f4d2
🔍 icon-search0x1f50d
🔐 icon-keyhole-circled0x1f510
🔑 icon-key0x1f511
🔒 icon-lock0x1f512
🔓 icon-lock-open-alt0x1f513
🔖 icon-tag0x1f516
🔧 icon-wrench0x1f527
🖉 icon-pencil0x1f589
🖊 icon-pencil-squared0x1f58a
🖋 icon-edit0x1f58b
🗀 icon-folder0x1f5c0
🗁 icon-folder-open0x1f5c1
🗅 icon-doc0x1f5c5
🗈 icon-doc-text0x1f5c8
🗑 icon-trashcan0x1f5d1
🗘 icon-arrows-cw0x1f5d8
🗩 icon-comment0x1f5e9
🗪 icon-comment-discussion0x1f5ea
🗴 icon-cancel0x1f5f4
🗵 icon-cancel-circled0x1f5f5
🗸 icon-ok0x1f5f8
🗹 icon-ok-circled0x1f5f9
🚫 icon-block0x1f6ab
🛠 icon-tools0x1f6e0